@@ -1,4 +1,4 @@
-## Copyright 2014-2016 Oliver Heimlich
+## Copyright 2014 Oliver Heimlich
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 ## @defmethod {@@infsup} columns (@var{A})
 ##
 ## Return the number of columns of @var{A}.
-## @seealso{@@infsup/numel, @@infsup/size, @@infsup/length, @@infsup/rows}
+## @seealso{@@infsup/numel, @@infsup/size, @@infsup/length, @@infsup/rows, @@infsup/end}
 ## @end defmethod
 
 ## Author: Oliver Heimlich
@@ -27,14 +27,16 @@
 
 function result = columns (a)
 
-if (nargin ~= 1)
+  if (nargin ~= 1)
     print_usage ();
     return
-endif
+  endif
 
-result = columns (a.inf);
+  result = columns (a.inf);
 
 endfunction
 
-%!test;
-%! assert (columns (infsup (zeros (3, 4))), 4);
+%!assert (columns (infsup (zeros (3, 4))), 4);
+%!assert (columns (infsup (zeros (0, 4))), 4);
+%!assert (columns (infsup (zeros (3, 0))), 0);
+%!assert (columns (infsup (zeros (3, 1))), 1);
