@@ -1,4 +1,4 @@
-## Copyright 2015-2016 Oliver Heimlich
+## Copyright 2015 Oliver Heimlich
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -19,14 +19,15 @@
 ##
 ## Return true if @var{A} is a square interval matrix.
 ##
-## @seealso{@@infsup/isvector, @@infsup/ismatrix, @@infsup/isscalar}
+## @seealso{@@infsup/isvector, @@infsup/isscalar}
 ## @end defmethod
 
 ## Author: Oliver Heimlich
 ## Keywords: interval
 ## Created: 2015-04-18
 
-## FIXME This function is only required, because of a regression in octave 4.0
+## FIXME: One happy day this function can be removed, because bug #44498 has
+## been solved with GNU Octave 5.1.0. Move tests to size.m.
 function result = issquare (A)
 
   if (nargin ~= 1)
