@@ -1,5 +1,5 @@
 /*
-  Copyright 2015-2016 Oliver Heimlich
+  Copyright 2015 Oliver Heimlich
   Copyright 2017 Joel Dahne
 
   This program is free software; you can redistribute it and/or modify
@@ -84,9 +84,6 @@ DEFUN_DLD (crlibm_function, args, nargout,
   const double      rnd      = args(1).scalar_value ();
   NDArray           arg1     = args(2).array_value ();
 
-  if (error_state)
-    return octave_value_list ();
-
   if (rnd == INFINITY)
     {
       // Round upwards
