@@ -1,5 +1,5 @@
 /*
-  Copyright 2015-2016 Oliver Heimlich
+  Copyright 2015 Oliver Heimlich
   Copyright 2017 Joel Dahne
   Copyright 2009-2017 Jaroslav Hajek
   Copyright 2009 VZLU Prague
@@ -217,7 +217,7 @@ void nthroot (
   for (octave_idx_type i = 0; i < n; i ++)
     {
       mpfr_set_d (mp, arg1.elem (i), MPFR_RNDZ);
-      mpfr_root (mp, mp, static_cast <uint64_t> (arg2.elem(i)), rnd);
+      mpfr_rootn_ui (mp, mp, static_cast <uint64_t> (arg2.elem(i)), rnd);
       arg1.elem (i) = mpfr_get_d (mp, rnd);
     }
 
@@ -391,8 +391,6 @@ DEFUN_DLD (mpfr_function_d, args, nargout,
       if (arg1.dims () != arg2.dims () || arg2.dims () != arg3.dims ())
         error ("mpfr_function_d: Array dimensions must agree!");
     }
-  if (error_state)
-    return octave_value_list ();
 
   // Choose the function to evaluate
   switch (nargin - 2)
@@ -491,8 +489,6 @@ DEFUN_DLD (mpfr_function_d, args, nargout,
         else if (function == "nthroot")
           {
             uint64NDArray n = args (3).uint64_array_value ();
-            if (error_state)
-              return octave_value_list ();
             nthroot (arg1, n, rnd);
           }
         else if (function == "plus")
