@@ -1,5 +1,5 @@
 /*
-  Copyright 2015-2016 Oliver Heimlich
+  Copyright 2015 Oliver Heimlich
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -128,9 +128,7 @@ DEFUN_DLD (mpfr_to_string_d, args, nargout,
     }
   
   const Matrix x = args (2).matrix_value ();
-  if (error_state)
-    return octave_value_list ();
-  
+
   char buf [768];
   mpfr_t mp;
   mpfr_t zero;
